SuperLU: SRC/mark_relax.c File Reference

SuperLU 7.0.1

Functions
mark_relax.c File Reference

Record the rows pivoted by the relaxed supernodes. More...

`#include "slu_ddefs.h"`
Include dependency graph for mark_relax.c:

## Functions
int | mark_relax (int n, const int *relax_end, const int *relax_fsupc, const int_t *xa_begin, const int_t *xa_end, const int_t *asub, int *marker)

## Detailed Description

Copyright (c) 2003, The Regents of the University of California, through Lawrence Berkeley National Laboratory (subject to receipt of any required approvals from U.S. Dept. of Energy)

All rights reserved.

The source code is distributed under BSD license, see the file License.txt at the top-level directory.

    -- SuperLU routine (version 4.0) --
    Lawrence Berkeley National Laboratory
    June 1, 2009

## Function Documentation

## ◆ mark_relax()

int mark_relax | ( | int | n,
|  | const int * | relax_end,
|  | const int * | relax_fsupc,
|  | const int_t * | xa_begin,
|  | const int_t * | xa_end,
|  | const int_t * | asub,
|  | int * | marker
| ) |  |

    Purpose
    =======
       mark_relax() - record the rows used by the relaxed supernodes.